var _ogre_vulkan_device_8h =
[
    [ "Ogre::VulkanDevice", "struct_ogre_1_1_vulkan_device.html", "struct_ogre_1_1_vulkan_device" ],
    [ "Ogre::VulkanDevice::ExtraVkFeatures", "struct_ogre_1_1_vulkan_device_1_1_extra_vk_features.html", "struct_ogre_1_1_vulkan_device_1_1_extra_vk_features" ],
    [ "Ogre::VulkanDevice::SelectedQueue", "struct_ogre_1_1_vulkan_device_1_1_selected_queue.html", "struct_ogre_1_1_vulkan_device_1_1_selected_queue" ],
    [ "Ogre::VulkanExternalDevice", "struct_ogre_1_1_vulkan_external_device.html", "struct_ogre_1_1_vulkan_external_device" ],
    [ "Ogre::VulkanExternalInstance", "struct_ogre_1_1_vulkan_external_instance.html", "struct_ogre_1_1_vulkan_external_instance" ],
    [ "Ogre::c_srcValidAccessFlags", "namespace_ogre.html#ae25fc08466018112ebbfaa616e88b38a", null ]
];